@@ -5,8 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_DECORATIONLABEL_H
-#define EVENTVIEWS_DECORATIONLABEL_H
+#pragma once
 
 #include "calendardecoration.h"
 
@@ -44,7 +43,7 @@ public Q_SLOTS:
 protected:
     void resizeEvent(QResizeEvent *) override;
     void mouseReleaseEvent(QMouseEvent *) override;
-    virtual void squeezeContentsToLabel();
+    void squeezeContentsToLabel();
     bool mAutomaticSqueeze = true;
     EventViews::CalendarDecoration::Element *mDecorationElement = nullptr;
     QString mShortText;
@@ -54,5 +53,3 @@ protected:
     QUrl mUrl;
 };
 }
-
-#endif
